@@ -15,19 +15,16 @@ from .helper.result_objects.compareResult import FaceCompareResult
 from .helper.result_objects.deleteResult import FaceDeleteResult
 from .helper.result_objects.enrollPredictResult import FaceEnrollPredictResult
 from .helper.result_objects.faceValidationResult import FaceValidationResult
+from .helper.result_objects.antispoofCheckResult import AntispoofCheckResult
 from .helper.result_objects.isoFaceResult import ISOFaceResult
 from .helper.utils import image_path_to_array
-from .settings.cacheType import CacheType
 from .settings.configuration import ConfigObject, PARAMETERS
 from .settings.loggingLevel import LoggingLevel
 from .settings.supportedPlatforms import SupportedPlatforms
 
 
 class FaceFactor(metaclass=Singleton):
-    """The FaceFactor class implements the methods for enrolling and predicting the Face module as part of the
-        Biometric Authentication.
-
-        It exposes five methods as part of the interface:
+    """The FaceFactor class implements the following methods :
 
         1. is_valid: Verifies the face of the user.
         2. estimate_age: Predicts the age of the face.
@@ -35,6 +32,9 @@ class FaceFactor(metaclass=Singleton):
         4. enroll: Enrolls the face of the user.
         5. predict: Predicts the face of the user.
         6. delete: Deletes the user from the system
+        7. antispoof_check: Check if the image is spoofed or not
+        8. get_iso_face: Takes the face image and gives back the image in ISO Spec format
+        9. compare_doc_with_face: Check if the images are of same person or not
 
         Parameters
         ----------
@@ -44,18 +44,9 @@ class FaceFactor(metaclass=Singleton):
         server_url : str
             The URL of the FaceFactor server.
 
-        local_storage_path : str (optional)
-            Absolute path to the local storage.
-
         logging_level : LoggingLevel (Optional)
             LoggingLevel needed while performing operation
 
-        tf_num_thread: int (Optional)
-            Number of thread to use for Tensorflow model inference
-
-        cache_type: CacheType (Optional)
-            To set the cache on / off
-
         config : ConfigObject (Optional)
             Configuration class object with parameters
 
@@ -72,17 +63,16 @@ class FaceFactor(metaclass=Singleton):
         enroll
         predict
         delete
+        antispoof_check
         get_iso_face
+        compare_doc_with_face
     """
 
     def __init__(
         self,
         api_key: str = None,
         server_url: str = None,
-        local_storage_path: str = None,
-        logging_level: LoggingLevel = LoggingLevel.off,
-        tf_num_thread: int = 0,
-        cache_type: CacheType = CacheType.OFF,
+        logging_level: LoggingLevel = LoggingLevel.off,        
         config: ConfigObject = None,
     ):
 
@@ -99,17 +89,7 @@ class FaceFactor(metaclass=Singleton):
                 or len(os.environ.get("PI_API_KEY")) <= 0
             ):
                 raise ValueError("API Key is required.")
-
-            if tf_num_thread is None and (
-                os.environ.get("PI_TF_NUM_THREAD") is None
-                or len(os.environ.get("PI_TF_NUM_THREAD")) <= 0
-            ):
-                tf_num_thread = 0
-
-            if tf_num_thread is None:
-                self._tf_num_thread = int(os.environ.get("PI_TF_NUM_THREAD"))
-            else:
-                self._tf_num_thread = tf_num_thread
+            
             if server_url is None:
                 self._server_url = os.environ.get("PI_SERVER_URL")
             else:
@@ -118,28 +98,16 @@ class FaceFactor(metaclass=Singleton):
                 self._api_key = os.environ.get("PI_API_KEY")
             else:
                 self._api_key = api_key
-            if local_storage_path is None:
-                self._local_storage_path = str(
-                    pathlib.Path(__file__)
-                    .parent.parent.joinpath("privateid_local_storage")
-                    .resolve()
-                )
-            else:
-                self._local_storage_path = local_storage_path
-
+            
             if self._server_url[-1] == "/":
                 self._server_url = self._server_url[:-1]
 
             self._config_object = config
-            self._logging_level = logging_level
-            self._cache_type = cache_type
+            self._logging_level = logging_level            
             self.face_factor = Face(
                 api_key=self._api_key,
                 server_url=self._server_url,
-                local_storage_path=self._local_storage_path,
-                logging_level=self._logging_level,
-                tf_num_thread=self._tf_num_thread,
-                cache_type=self._cache_type,
+                logging_level=self._logging_level,                
                 config_object=self._config_object,
             )
             self.message = Message()
@@ -222,6 +190,13 @@ class FaceFactor(metaclass=Singleton):
                 img_data = image_path_to_array(image_path, input_format=input_format)
             if img_data is None:
                 return FaceValidationResult(message=self.message.IS_VALID_ERROR)
+
+            # Check image dimensions
+            if img_data.shape[0] <= 224 or img_data.shape[1] <= 224:
+                return FaceValidationResult(
+                    message="Image dimensions should be greater than 224x224."
+                )
+
             return self.face_factor.is_valid(image_data=img_data, config_object=config)
         except Exception as e:
             print("Oops: {}\nTrace: {}".format(e, traceback.format_exc()))
@@ -291,6 +266,13 @@ class FaceFactor(metaclass=Singleton):
                 img_data = image_path_to_array(image_path, input_format=input_format)
             if img_data is None:
                 return FaceValidationResult(message=self.message.AGE_ESTIMATE_ERROR)
+
+            # Check image dimensions
+            if img_data.shape[0] <= 224 or img_data.shape[1] <= 224:
+                return FaceValidationResult(
+                    message="Image dimensions should be greater than 224x224."
+                )
+
             return self.face_factor.estimate_age(
                 image_data=img_data, config_object=config
             )
@@ -372,6 +354,13 @@ class FaceFactor(metaclass=Singleton):
                 return FaceEnrollPredictResult(
                     message=self.message.EXCEPTION_ERROR_ENROLL
                 )
+
+            # Check image dimensions
+            if img_data.shape[0] <= 224 or img_data.shape[1] <= 224:
+                return FaceEnrollPredictResult(
+                    message="Image dimensions should be greater than 224x224."
+                )
+
             return self.face_factor.enroll(image_data=img_data, config_object=config)
         except Exception as e:
             print("Oops: {}\nTrace: {}".format(e, traceback.format_exc()))
@@ -447,6 +436,13 @@ class FaceFactor(metaclass=Singleton):
                 img_data = image_path_to_array(image_path, input_format=input_format)
             if img_data is None:
                 return ISOFaceResult(message=self.message.EXCEPTION_ERROR_GET_ISO_FACE)
+
+            # Check image dimensions
+            if img_data.shape[0] <= 224 or img_data.shape[1] <= 224:
+                return ISOFaceResult(
+                    message="Image dimensions should be greater than 224x224."
+                )
+
             return self.face_factor.get_iso_face(
                 image_data=img_data, config_object=config
             )
@@ -528,6 +524,13 @@ class FaceFactor(metaclass=Singleton):
                 return FaceEnrollPredictResult(
                     message=self.message.EXCEPTION_ERROR_PREDICT
                 )
+
+            # Check image dimensions
+            if img_data.shape[0] <= 224 or img_data.shape[1] <= 224:
+                return FaceEnrollPredictResult(
+                    message="Image dimensions should be greater than 224x224."
+                )
+
             return self.face_factor.predict(image_data=img_data, config_object=config)
         except Exception as e:
             print("Oops: {}\nTrace: {}".format(e, traceback.format_exc()))
@@ -535,75 +538,6 @@ class FaceFactor(metaclass=Singleton):
                 "Issue Tracker:: \nhttps://github.com/prividentity/cryptonets-python-sdk/issues"
             )
             return FaceEnrollPredictResult(message=self.message.EXCEPTION_ERROR_PREDICT)
-    def _doc_scan_face(
-        self,
-        image_path: str = None,
-        image_data: np.array = None,
-        config: ConfigObject = None,
-    ) :
-        try:
-            if (
-                config is not None
-                and PARAMETERS.INPUT_IMAGE_FORMAT in config.config_param
-            ):
-                input_format = config.config_param[PARAMETERS.INPUT_IMAGE_FORMAT]
-            elif (
-                self.config is not None
-                and PARAMETERS.INPUT_IMAGE_FORMAT in self.config.config_param
-            ):
-                input_format = self.config.config_param[PARAMETERS.INPUT_IMAGE_FORMAT]
-            else:
-                input_format = "rgb"
-            if (image_path is not None and image_data is not None) or (
-                image_path is None and image_data is None
-            ):
-                return "Specify either image_path or image_data"
-                
-            img_data = None
-            if image_data is not None:
-                if not isinstance(image_data, np.ndarray):
-                    return "Required numpy array in RGB/RGBA/BGR format"
-                
-                img_data = image_data
-            if image_path is not None and len(image_path) > 0:
-                if not os.path.exists(image_path):
-                    return self.message.get_message(101)
-            img_data = image_path_to_array(image_path, input_format)
-            if img_data is None:
-                return self.message.EXCEPTION_ERROR_PREDICT
-            return self.face_factor._doc_scan_face(image_data=img_data, config_object=config)
-        except Exception as e:
-            print("Oops: {}\nTrace: {}".format(e, traceback.format_exc()))
-            print(
-                "Issue Tracker:: \nhttps://github.com/prividentity/cryptonets-python-sdk/issues"
-            )
-            return self.message.EXCEPTION_ERROR_PREDICT
-
-    def delete(self, puid: str,config: ConfigObject = None)-> FaceDeleteResult:
-        """Deletes the enrollment from the face recognition server
-
-        Parameters
-        ----------
-        puid
-            PUID of the enrolled image
-
-        Returns
-        -------
-        FaceDeleteResult
-            status: int [0 if successful -1 if unsuccessful]
-
-            message: str [Message from the operation]
-        """
-        try:
-            if puid is None:
-                return FaceDeleteResult(message="Missing PUID")
-            return self.face_factor.delete(puid,config)
-        except Exception as e:
-            print("Oops: {}\nTrace: {}".format(e, traceback.format_exc()))
-            print(
-                "Issue Tracker:: \nhttps://github.com/prividentity/cryptonets-python-sdk/issues"
-            )
-            return FaceDeleteResult(message=self.message.EXCEPTION_ERROR_DELETE)
 
     def compare_doc_with_face(
         self,
@@ -617,25 +551,25 @@ class FaceFactor(metaclass=Singleton):
 
         Parameters
         ----------
-        image_path_1
-            Directory path to the first image file
+        face_path
+            Directory path to the face image file
 
-        image_path_2
-            Directory path to the second image file
+        doc_path
+            Directory path to the document image file
 
         config (Optional)
             Additional configuration parameters for the operation
 
-        image_data_1 (Optional)
-            First Image data in numpy RGB format
+        face_data (Optional)
+            Face Image data in numpy RGB format
 
-        image_data_2 (Optional)
-            Second Image data in numpy RGB format
+        doc_data (Optional)
+            Document Image data in numpy RGB format
 
         Returns
         -------
         FaceCompareResult
-            status: int 
+            status: int
 
             message: str [Message from the operation]
 
@@ -701,6 +635,17 @@ class FaceFactor(metaclass=Singleton):
                     return FaceCompareResult(
                         message=self.message.EXCEPTION_ERROR_COMPARE
                     )
+
+            # Check image dimensions for both images
+            if img_data_1.shape[0] <= 224 or img_data_1.shape[1] <= 224:
+                return FaceCompareResult(
+                    message="Image dimensions should be greater than 224x224."
+                )
+            if img_data_2.shape[0] <= 224 or img_data_2.shape[1] <= 224:
+                return FaceCompareResult(
+                    message="Image dimensions should be greater than 224x224."
+                )
+
             return self.face_factor.compare_doc_with_face(
                 face_data=img_data_1, doc_data=img_data_2, config_object=config
             )
@@ -711,7 +656,6 @@ class FaceFactor(metaclass=Singleton):
             )
             return FaceCompareResult(message=self.message.EXCEPTION_ERROR_COMPARE)
 
-
     def compare(
         self,
         image_path_1: str = None,
@@ -812,6 +756,17 @@ class FaceFactor(metaclass=Singleton):
                     return FaceCompareResult(
                         message=self.message.EXCEPTION_ERROR_COMPARE
                     )
+
+            # Check image dimensions for both images
+            if img_data_1.shape[0] <= 224 or img_data_1.shape[1] <= 224:
+                return FaceCompareResult(
+                    message="Image dimensions should be greater than 224x224."
+                )
+            if img_data_2.shape[0] <= 224 or img_data_2.shape[1] <= 224:
+                return FaceCompareResult(
+                    message="Image dimensions should be greater than 224x224."
+                )
+
             return self.face_factor.compare(
                 image_data_1=img_data_1, image_data_2=img_data_2, config_object=config
             )
@@ -821,6 +776,116 @@ class FaceFactor(metaclass=Singleton):
                 "Issue Tracker:: \nhttps://github.com/prividentity/cryptonets-python-sdk/issues"
             )
             return FaceCompareResult(message=self.message.EXCEPTION_ERROR_COMPARE)
+    def antispoof_check(
+        self,
+        image_path: str = None,
+        image_data: np.array = None,
+        config: ConfigObject = None,
+    ) -> AntispoofCheckResult:
+        """Check if the image is spoofed or not
+
+        Parameters
+        ----------
+        image_path
+            Directory path to the image file
+
+        config (Optional)
+            Additional configuration parameters for the operation
+
+        image_data (Optional)
+            Image data in numpy RGB format
+
+        Returns
+        -------
+        AntispoofCheckResult
+
+            status: int [0 if successful -1 if unsuccessful]
+            
+            message: str [Message from the operation]
+
+            is_antispoof: bool [True if spoofed, False if not spoofed]
+        
+        """
+        try:
+            if (
+                config is not None
+                and PARAMETERS.INPUT_IMAGE_FORMAT in config.config_param
+            ):
+                input_format = config.config_param[PARAMETERS.INPUT_IMAGE_FORMAT]
+            elif (
+                self.config is not None
+                and PARAMETERS.INPUT_IMAGE_FORMAT in self.config.config_param
+            ):
+                input_format = self.config.config_param[PARAMETERS.INPUT_IMAGE_FORMAT]
+            else:
+                input_format = "rgb"
+            if (image_path is not None and image_data is not None) or (
+                image_path is None and image_data is None
+            ):
+                return AntispoofCheckResult(
+                    message="Specify either image_path or image_data"
+                )
+            img_data = None
+            if image_data is not None:
+                if not isinstance(image_data, np.ndarray):
+                    return AntispoofCheckResult(
+                        message="Required numpy array in RGB/RGBA/BGR format"
+                    )
+                img_data = image_data
+            if image_path is not None and len(image_path) > 0:
+                if not os.path.exists(image_path):
+                    return AntispoofCheckResult(message=self.message.get_message(101))
+                img_data = image_path_to_array(image_path, input_format=input_format)
+            if img_data is None:
+                return AntispoofCheckResult(message=self.message.ANTISPOOF_CHECK_ERROR)
+
+            # Check image dimensions
+            if img_data.shape[0] <= 224 or img_data.shape[1] <= 224:
+                return AntispoofCheckResult(
+                    message="Image dimensions should be greater than 224x224."
+                )
+
+            return self.face_factor.antispoof_check(
+                image_data=img_data, config_object=config
+            )
+        except Exception as e:
+            print("Oops: {}\nTrace: {}".format(e, traceback.format_exc()))
+            print(
+                "Issue Tracker:: \nhttps://github.com/prividentity/cryptonets-python-sdk/issues"
+            )
+            return AntispoofCheckResult(message=self.message.ANTISPOOF_CHECK_ERROR)
+
+    def delete(self, puid: str ,config_object: ConfigObject = None ) -> FaceDeleteResult:
+        """Deletes a user by their PUID from the system
+
+        Parameters
+        ----------
+        puid : str
+            The PUID (Private User ID) of the user to delete
+        
+        config_object : ConfigObject (Optional)
+            Additional configuration parameters for the operation
+
+        Returns
+        -------
+        FaceDeleteResult
+            Result of the delete operation
+        """
+        if puid is None:
+            return FaceDeleteResult(message=self.message.MISSING_ARGUMENT.format("puid"))   
+        elif puid == '':
+            return FaceDeleteResult(message=self.message.INVALID_ARGUMENT.format("puid"))
+        
+        try:
+            return self.face_factor.delete(puid,config_object=config_object)
+        except Exception as e:
+            import traceback
+            print(f"Delete operation failed: {e}\nTrace: {traceback.format_exc()}")
+            print(
+                "Issue Tracker:: \nhttps://github.com/prividentity/cryptonets-python-sdk/issues"
+            )
+            return FaceDeleteResult(status=-1, message=self.message.EXCEPTION_ERROR_DELETE)
+
 
     @property
     def api_key(self) -> str:
@@ -829,11 +894,7 @@ class FaceFactor(metaclass=Singleton):
     @property
     def server_url(self) -> str:
         return self._server_url
-
-    @property
-    def local_storage_path(self) -> str:
-        return self._local_storage_path
-
+    
     @property
     def logging_level(self) -> LoggingLevel:
         return self._logging_level
@@ -849,22 +910,14 @@ class FaceFactor(metaclass=Singleton):
     @server_url.setter
     def server_url(self, value):
         self._server_url = value
-
-    @local_storage_path.setter
-    def local_storage_path(self, value):
-        self._local_storage_path = value
-
+    
     @logging_level.setter
     def logging_level(self, value):
         self._logging_level = value
 
     @config.setter
     def config(self, value):
-        self._config_object = value
-
-    @property
-    def version(self) -> str:
-        return self._version
+        self._config_object = value    
 
 
 if __name__ == "__main__":
